bayespy.inference.vmp.nodes.deterministic.Deterministic.add_plate_axis
======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.add_plate_axis